<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Prohlížeč obrázků</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Verze:</translation>
    </message>
</context>
<context>
    <name>AlbumBTContent</name>
    <message>
        <source>image</source>
        <translation>obrázek</translation>
    </message>
    <message>
        <source>images</source>
        <translation>obrázků</translation>
    </message>
    <message>
        <source>album</source>
        <translation>album</translation>
    </message>
    <message>
        <source>albums</source>
        <translation>alb</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Spravovat seřízení</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Seřízení:</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nové album</translation>
    </message>
    <message>
        <source>Unnamed</source>
        <translation>Nepojmenovaný</translation>
    </message>
</context>
<context>
    <name>AlbumDelegate</name>
    <message>
        <source>Recent imported</source>
        <translation>Nedávno zavedené</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Moje oblíbené</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Are your sure to delete this album?</source>
        <translation>Jste si jistý, že chcete smazat toto album?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
</context>
<context>
    <name>AlbumPanel</name>
    <message>
        <source>Back</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Moje oblíbené</translation>
    </message>
    <message>
        <source>Timeline</source>
        <translation>Časová osa</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Přidat</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Můžete přidat seřizovací adresář nebo obrázky táhnout a upustit na časovou osu</translation>
    </message>
</context>
<context>
    <name>AlbumsView</name>
    <message>
        <source>Unnamed</source>
        <translation>Nepojmenovaný</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Pohled</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Promítání</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Přejmenovat</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Prohlížeč obrázků</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Obrázky</translation>
    </message>
</context>
<context>
    <name>DirImportDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Are you sure to add the pictures to the album?</source>
        <translation>Jste si jistý, že chcete přidat obrázky do alba?</translation>
    </message>
    <message>
        <source>Sync and Create</source>
        <translation>Seřídit a smazat</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Seřídit</translation>
    </message>
    <message>
        <source>Are you sure to add to the sync list and create the album named after this folder?</source>
        <translation>Jste si jistý, že chcete přidat seřizovací seznam a vytvořit album pojmenované podle této složky?</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</source>
        <translation>JPEG (*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</translation>
    </message>
    <message>
        <source>Exported successfully</source>
        <translation>Úspěšně vyvedeno</translation>
    </message>
    <message>
        <source>Failed to export</source>
        <translation>Nepodařilo se vyvést</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
</context>
<context>
    <name>FileDeleteDialog</name>
    <message>
        <source>Are you sure to throw pictures to TRASH?</source>
        <translation>Jste si jistý, že chcete obrázky hodit do koše?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Image info</source>
        <translation>Informace o obrázku</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Tento soubor obsahuje více stránek, pro zobrazení všech stránek použijte službu Evince.</translation>
    </message>
</context>
<context>
    <name>ImagesView</name>
    <message>
        <source>View</source>
        <translation>Pohled</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Promítání</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Tisk</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Kopírovat do schránky</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Odstranit z alba</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Oblíbené</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Neoblíbené</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Otočit po směru hodinových ručiček</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Otočit proti směru hodinových ručiček</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nastavit jako pozadí plochy</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Zobrazit ve správci souborů</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informace o obrázku</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Přidat</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Můžete přidat seřizovací adresář nebo obrázky táhnout a upustit na časovou osu</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Přidat do alba</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Přidat do nového alba</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Otevřít adresář</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Nemáte oprávnění k zobrazení obrázku</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Date photoed</source>
        <translation>Pořízeno</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Změněno</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File size</source>
        <translation>Velikost souboru</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Barevný prostor</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Režim osvitu</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Program osvitu</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Doba osvitu</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Blesk</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Clona</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Ohnisková vzdálenost</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Největší clona</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Měřicí režim</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Vyvážení bílé</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Náhrada za blesk</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Model fotoaparátu</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Model čočky</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Žádná změna velikosti</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Přizpůsobit stranu obrázku</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Přizpůsobit obrázek straně</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Změnit velikost na:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Milimetry</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Centimetry</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Palce</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Poloha obrázku</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Změna velikosti</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Nastavení obrázku</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Rolování</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Přepínač</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Promítání</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Prstenec</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Vybrat adresář</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Tento adresář je pro seřízení zakázán</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Přidat složku</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Správa seřízení adresáře</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>Seznam adresářů je prázdný</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Zrušit seřízení</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Obrázky</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Zařízení bylo odstraněno</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Tento adresář už neexistuje</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Počítá se...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Zobrazení obrázku</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Pohled</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Promítání</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Ukončit promítání</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Odstranit z alba</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Oblíbené</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Neoblíbené</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Otočit po směru hodinových ručiček</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Otočit proti směru hodinových ručiček</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nastavit jako pozadí plochy</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Zobrazit ve správci souborů</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informace o obrázku</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Předchozí</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Další</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Předchozí obrazovka</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Další obrazovka</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nové album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Přejmenovat</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Ukončit</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Zobrazit zkratky</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Zadejte, prosím, novou zkratku</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Zkratky</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Zobrazit obrázek</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Obnovit výchozí</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Pohled</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Promítání</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Ukončit promítání</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Tisk</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Odstranit z alba</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Oblíbené</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Neoblíbené</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Otočit po směru hodinových ručiček</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Otočit proti směru hodinových ručiček</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nastavit jako pozadí plochy</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Zobrazit ve správci souborů</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informace o obrázku</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Nové album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Přejmenovat</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
</context>
<context>
    <name>SlideShowPanel</name>
    <message>
        <source>End show</source>
        <translation>Ukončit promítání</translation>
    </message>
    <message>
        <source>Pause/Play</source>
        <translation>Pozastavit/Přehrát</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Nastavení promítání</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Přepnout efekt</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Doba trvání</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Přepnout dobu trvání</translation>
    </message>
    <message>
        <source>second</source>
        <translation>sekunda</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Správa obrázků</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Moje oblíbené</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Velikost 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Přizpůsobit oknu</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Otočit proti směru hodinových ručiček</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Otočit po směru hodinových ručiček</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Neoblíbené</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Oblíbené</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Nenalezeny žádné obrázkové soubory</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Otevřít obrázek</translation>
    </message>
</context>
<context>
    <name>TimelineBTContent</name>
    <message>
        <source>%1 image</source>
        <translation>%1 obrázek</translation>
    </message>
    <message>
        <source>%1 images</source>
        <translation>%1 obrázků</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Spravovat seřízení</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Seřízení:</translation>
    </message>
</context>
<context>
    <name>TimelinePanel</name>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Přidat</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Můžete přidat seřizovací adresář nebo obrázky táhnout a upustit na časovou osu</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Přidat do alba</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Přidat do nového alba</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Pohled</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Promítání</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Tisk</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Kopírovat do schránky</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Oblíbené</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Neoblíbené</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Otočit po směru hodinových ručiček</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Otočit proti směru hodinových ručiček</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nastavit jako pozadí plochy</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Zobrazit ve správci souborů</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informace o obrázku</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Nastavení promítání</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Efekt</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Doba trvání</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Zkratky</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Pohled</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
</context>
<context>
    <name>TopAlbumTips</name>
    <message>
        <source>dd MMMM yyyy</source>
        <translation>dd MMMM rrrr</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Moje oblíbené</translation>
    </message>
    <message>
        <source>Recent imported</source>
        <translation>Nedávno zavedené</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Nové album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
        <translation>Prohlížeč obrázků je příjemný a snadno ovladatelný správce obrázků</translation>
    </message>
    <message>
        <source>It is featured with image management, image viewing and basic image editing.</source>
        <translation>Toto je spojeno se správou obrázků, zobrazení obrázků a základní úpravy obrázků.</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Tmavý vzhled</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Prohlížeč obrázků je příjemný a snadno ovladatelný správce obrázků.</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Časová osa</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Přidat do alba</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Přidat do nového alba</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Opustit celou obrazovku</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Celá obrazovka</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Promítání</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Tisk</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Kopírovat do schránky</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Odstranit z alba</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Oblíbené</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Neoblíbené</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Ukázat pohybové okno</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Skrýt pohybové okno</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Otočit po směru hodinových ručiček</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Otočit proti směru hodinových ručiček</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Nastavit jako pozadí plochy</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Zobrazit ve správci souborů</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informace o obrázku</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Otevřít obrázek</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Všechny obrázky</translation>
    </message>
</context>
</TS>